#' A vector containing names of the resampling methods.
#'
#' @description
#' `methodNames` is a vector containing names of the resampling methods.
#'
#' @return This function returns a vector of strings.
#'
#'
#' @examples
#'
#' # check the names
#'
#' methodNames
#'
#' @export


methodNames <- c("dimp", "missForest", "miceRanger","knn","pmm")
